# -*- coding: utf-8 -*-
from setuphelpers import *
from waptcrypto import SSLCertificate

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

Procedure:
1-Make sure all your allowed Public WAPT certificates are in the same directory
2-Change path_to_all_allowed_wapt_crts variable with this directory
3-Run the update-package 
4-Copy and paste the returned list in allowed_wapt_crt_sha1_list variable
5-Rename and upload this package

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
allowed_wapt_crt_sha1_list = [
    "5361b4b6f772bbae427template509c41e297666",
    "5e37d49c2a014a9436btemplate7ea0ea7a9e8323",
]



def install():
    # Declaring local variables
    wapt_ssl_path = makepath(WAPT.wapt_base_dir, "ssl")

    # Cleaning WAPT SSL Certificates
    print("Cleaning: WAPT SSL Certificates")
    for filepath in glob.glob(makepath(wapt_ssl_path, "*.*")):
        if filepath.endswith(".crt"):
            crt_fingerprint_sha1 = SSLCertificate(filepath).fingerprint_sha1
            crt_cn = SSLCertificate(filepath).cn
            if crt_fingerprint_sha1 not in allowed_wapt_crt_sha1_list:
                print("ERROR:       %s (CN: %s) is NOT an allowed certificate" % (filepath, crt_cn))
                print("Removing:    %s" % (filepath))
                remove_file(filepath)
            else:
                print("OK:          %s (CN: %s) is an allowed certificate" % (filepath, crt_cn))
        elif filepath.endswith(".pem"):
            print("Removing:        %s since no private key has to be here" % (filepath))
            remove_file(filepath)
        else:
            print("Removing:        %s since no other file needs to be here" % (filepath))
            remove_file(filepath)


def audit():
    # Declaring local variables
    result = "OK"
    wapt_ssl_path = makepath(WAPT.wapt_base_dir, "ssl")

    # Auditing WAPT SSL Certificates
    print("Auditing: WAPT SSL Certificates")
    for filepath in glob.glob(makepath(wapt_ssl_path, "*.*")):
        if not filepath.endswith(".crt") and not filepath.endswith(".pem"):
            print("WARNING:     %s is NOT an allowed file since no other file needs to be here" % (filepath))
            result = "WARNING"

        if filepath.endswith(".pem"):
            print("WARNING:     %s is NOT an allowed file since no private key has to be here" % (filepath))
            result = "WARNING"

        if filepath.endswith(".crt"):
            crt_fingerprint_sha1 = SSLCertificate(filepath).fingerprint_sha1
            crt_cn = SSLCertificate(filepath).cn
            if crt_fingerprint_sha1 not in allowed_wapt_crt_sha1_list:
                print("ERROR:       %s (CN: %s) is NOT an allowed certificate" % (filepath, crt_cn))
                result = "ERROR"
            else:
                print("OK:          %s (CN: %s) is an allowed certificate" % (filepath, crt_cn))

    # if result == "ERROR":
    if result != "OK":
        print("You have to reinstall this package to remove unallowed certificates or files")
    return result
